==> haskell-http-client-0.5.12.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.12.1
id: http-client-0.5.12.1-7z3Z1sBbGzE3RywK1atXkS
key: http-client-0.5.12.1-7z3Z1sBbGzE3RywK1atXkS
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 811278062265fa9d49c09dcfc1f18ddc
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.2/site-local/http-client-0.5.12.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/http-client-0.5.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/http-client-0.5.12.1
hs-libraries: HShttp-client-0.5.12.1-7z3Z1sBbGzE3RywK1atXkS
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-Lpok6Slvjvz80G696NvwZk
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.6.3.5-Ey5nELlCFMCCJfToLl8AVa
    streaming-commons-0.2.0.0-GRsG6b0fzWHAMDiU7gEtKk
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             http-types-0.12.1-Lpok6Slvjvz80G696NvwZk=f7221635e6aaec4edcf976b9c4e3aae5
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=a6b0b26ea14b9a093ef6d86c6b4d483f
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             network-2.6.3.5-Ey5nELlCFMCCJfToLl8AVa=2ccacb7c7507f165c3f664c3e6d39bf6
             streaming-commons-0.2.0.0-GRsG6b0fzWHAMDiU7gEtKk=aa14b65b7dd5768cf4dd445228474bbe
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=41d12cf00836681a13a87be0eaaa8ed3
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=4e5a3cc60c19a55cf0c018ef5859acbb
             exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR=9f60f161536a7d4278dffe801494d805
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=552cb76a5e53a808564c851a382c09ce
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=e67c2acc5ecf4421eadbd12de2e86a0b
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
             stm-2.4.5.0=fc4e40e3aa6203460dfa01934bcd44f0
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=d49fd54c7cc8ca7cdc7f65925221d670
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.12.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.12.1
id: http-client-0.5.12.1-8niwn8izYIzLfy28z2Y2f6
key: http-client-0.5.12.1-8niwn8izYIzLfy28z2Y2f6
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 8919b9e6821b72d1aad6e194a4d8d0c1
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.2/site-local/http-client-0.5.12.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/http-client-0.5.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/http-client-0.5.12.1
hs-libraries: HShttp-client-0.5.12.1-8niwn8izYIzLfy28z2Y2f6
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-9G9IqNV3a1x8yQKrYijGm4
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.6.3.5-3iG8FzHVTj33yRWcu7gfSt
    streaming-commons-0.2.0.0-C9EfJAhiL2wFC7Zs6O0vit
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             http-types-0.12.1-9G9IqNV3a1x8yQKrYijGm4=2c2dad893bbea8aafb573db454497a33
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=a6b0b26ea14b9a093ef6d86c6b4d483f
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
             network-2.6.3.5-3iG8FzHVTj33yRWcu7gfSt=d1eb7c9f9a3a0cc5a7f6358d4fbd8f71
             streaming-commons-0.2.0.0-C9EfJAhiL2wFC7Zs6O0vit=c57a679d651b9abec1fb8d2247480043
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=41d12cf00836681a13a87be0eaaa8ed3
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ed2d5adcedeb6833cc2a392fb853e830
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=4e5a3cc60c19a55cf0c018ef5859acbb
             exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf=90dd74da021381146ba64944278df775
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=552cb76a5e53a808564c851a382c09ce
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=e67c2acc5ecf4421eadbd12de2e86a0b
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
             stm-2.4.5.0=fc4e40e3aa6203460dfa01934bcd44f0
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=d49fd54c7cc8ca7cdc7f65925221d670
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
